"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.getAddComponentActions = void 0;
const tslib_1 = require("tslib");
const path_1 = tslib_1.__importDefault(require("path"));
const change_case_1 = require("change-case");
const utils_1 = require("../../utils");
const getAddComponentActions = (data) => {
    let actions = [];
    const excludeExports = data.excludeExports || ['utils', '_common', 'foundation-testing'];
    const hostDirectives = data.hostDirectives || [];
    data.components.forEach((name) => {
        const nameParamCase = (0, change_case_1.paramCase)(name);
        const isHostDirective = hostDirectives.includes(nameParamCase);
        let uiComponents = (0, utils_1.getUIDirectoryNames)().filter((componentName) => !excludeExports.includes(componentName));
        if (!uiComponents.includes(nameParamCase)) {
            uiComponents = [...uiComponents, nameParamCase].sort();
        }
        const componentActions = [
            {
                type: 'add',
                path: path_1.default.resolve(__dirname, `../../../../../foundation/foundation-ui/src/${nameParamCase}/${nameParamCase}.ts`),
                templateFile: path_1.default.resolve(__dirname, '../templates/component/ui/component.ts.hbs'),
                data: {
                    baseComponent: data.baseComponent,
                    name,
                    isHostDirective,
                },
                force: data.force,
            },
            {
                type: 'add',
                path: path_1.default.resolve(__dirname, `../../../../../foundation/foundation-ui/src/${nameParamCase}/${nameParamCase}.template.ts`),
                templateFile: path_1.default.resolve(__dirname, '../templates/component/ui/component.template.ts.hbs'),
                data: {
                    baseComponent: data.baseComponent,
                    name,
                    isHostDirective,
                },
                force: data.force,
            },
            {
                type: 'add',
                path: path_1.default.resolve(__dirname, `../../../../../foundation/foundation-ui/src/${nameParamCase}/${nameParamCase}.test.ts`),
                templateFile: path_1.default.resolve(__dirname, '../templates/component/ui/component.test.ts.hbs'),
                data: {
                    baseComponent: data.baseComponent,
                    name,
                    isHostDirective,
                },
                force: data.force,
            },
            {
                type: 'add',
                path: path_1.default.resolve(__dirname, `../../../../../foundation/foundation-ui/src/${nameParamCase}/${nameParamCase}.styles.ts`),
                templateFile: path_1.default.resolve(__dirname, '../templates/component/ui/component.styles.ts.hbs'),
                data: {
                    baseComponent: data.baseComponent,
                    name,
                    isHostDirective,
                },
                force: data.force,
            },
            {
                type: 'add',
                path: path_1.default.resolve(__dirname, `../../../../../foundation/foundation-ui/src/${nameParamCase}/index.ts`),
                templateFile: path_1.default.resolve(__dirname, '../templates/component/ui/index.ts.hbs'),
                data: {
                    baseComponent: data.baseComponent,
                    name,
                    isHostDirective,
                },
                force: data.force,
            },
            {
                type: 'add',
                path: path_1.default.resolve(__dirname, `../../../../../foundation/foundation-ui/src/${nameParamCase}/README.md`),
                templateFile: path_1.default.resolve(__dirname, '../templates/component/ui/README.md.hbs'),
                data: {
                    baseComponent: data.baseComponent,
                    name,
                    isHostDirective,
                },
                force: data.force,
            },
            {
                type: 'add',
                path: path_1.default.resolve(__dirname, `../../../../../foundation/foundation-ui/src/index.ts`),
                templateFile: path_1.default.resolve(__dirname, '../templates/component/index.ts.hbs'),
                data: {
                    baseComponent: data.baseComponent,
                    name,
                    uiComponents,
                    isHostDirective,
                },
                force: data.force,
            },
        ];
        actions = [...actions, ...componentActions];
        if (data.designSystemChoices && data.designSystemChoices.length) {
            data.designSystemChoices.forEach((dsName) => {
                let dsComponents = (0, utils_1.getDsDirectoryNames)(dsName).filter((componentName) => !excludeExports.includes(componentName));
                if (!dsComponents.includes(nameParamCase)) {
                    dsComponents = [...dsComponents, nameParamCase].sort();
                }
                const componentDsActions = [
                    {
                        type: 'add',
                        path: path_1.default.resolve(__dirname, `../../../../../foundation/foundation-ds/${dsName}/src/${nameParamCase}/${nameParamCase}.ts`),
                        templateFile: path_1.default.resolve(__dirname, '../templates/component/ds/component.ts.hbs'),
                        data: {
                            baseComponent: data.baseComponent,
                            dsName,
                            name,
                            isHostDirective,
                        },
                        force: data.force,
                    },
                    {
                        type: 'add',
                        dsName,
                        path: path_1.default.resolve(__dirname, `../../../../../foundation/foundation-ds/${dsName}/src/${nameParamCase}/${nameParamCase}.styles.ts`),
                        templateFile: path_1.default.resolve(__dirname, '../templates/component/ds/component.styles.ts.hbs'),
                        data: {
                            baseComponent: data.baseComponent,
                            dsName,
                            name,
                            isHostDirective,
                        },
                        force: data.force,
                    },
                    {
                        type: 'add',
                        dsName,
                        path: path_1.default.resolve(__dirname, `../../../../../foundation/foundation-ds/${dsName}/src/${nameParamCase}/${nameParamCase}.template.ts`),
                        templateFile: path_1.default.resolve(__dirname, '../templates/component/ds/component.template.ts.hbs'),
                        data: {
                            baseComponent: data.baseComponent,
                            dsName,
                            name,
                            isHostDirective,
                        },
                        force: data.force,
                    },
                    {
                        type: 'add',
                        path: path_1.default.resolve(__dirname, `../../../../../foundation/foundation-ds/${dsName}/src/${nameParamCase}/${nameParamCase}.stories.ts`),
                        templateFile: path_1.default.resolve(__dirname, '../templates/component/ds/component.stories.ts.hbs'),
                        data: {
                            baseComponent: data.baseComponent,
                            dsName,
                            name,
                            isHostDirective,
                        },
                        force: data.force,
                    },
                    {
                        type: 'add',
                        path: path_1.default.resolve(__dirname, `../../../../../foundation/foundation-ds/${dsName}/src/${nameParamCase}/fixtures/base.html`),
                        templateFile: path_1.default.resolve(__dirname, '../templates/component/ds/fixtures/base.html.hbs'),
                        data: {
                            baseComponent: data.baseComponent,
                            dsName,
                            name,
                            isHostDirective,
                        },
                        force: data.force,
                    },
                    {
                        type: 'add',
                        path: path_1.default.resolve(__dirname, `../../../../../foundation/foundation-ds/${dsName}/src/${nameParamCase}/index.ts`),
                        templateFile: path_1.default.resolve(__dirname, '../templates/component/ds/index.ts.hbs'),
                        data: {
                            baseComponent: data.baseComponent,
                            dsName,
                            name,
                            isHostDirective,
                        },
                        force: data.force,
                    },
                    {
                        type: 'add',
                        path: path_1.default.resolve(__dirname, `../../../../../foundation/foundation-ds/${dsName}/src/${nameParamCase}/README.md`),
                        templateFile: path_1.default.resolve(__dirname, '../templates/component/ds/README.md.hbs'),
                        data: {
                            baseComponent: data.baseComponent,
                            dsName,
                            name,
                            isHostDirective,
                        },
                        force: data.force,
                    },
                    {
                        type: 'add',
                        path: path_1.default.resolve(__dirname, `../../../../../foundation/foundation-ds/${dsName}/src/index.ts`),
                        templateFile: path_1.default.resolve(__dirname, '../templates/component/index.ts.hbs'),
                        data: {
                            baseComponent: data.baseComponent,
                            dsName,
                            name,
                            dsComponents,
                            isHostDirective,
                        },
                        force: data.force,
                    },
                ];
                actions = [...actions, ...componentDsActions];
            });
        }
    });
    return actions;
};
exports.getAddComponentActions = getAddComponentActions;
