"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.setActionTypes = exports.FileSystemActions = exports.FileSystemActionType = void 0;
const tslib_1 = require("tslib");
const path_1 = tslib_1.__importDefault(require("path"));
const Utils = tslib_1.__importStar(require("../../utils"));
var FileSystemActionType;
(function (FileSystemActionType) {
    FileSystemActionType["createDirectory"] = "Create directory";
    FileSystemActionType["createPath"] = "Create path";
    FileSystemActionType["replaceContent"] = "Replace content";
})(FileSystemActionType = exports.FileSystemActionType || (exports.FileSystemActionType = {}));
var FileSystemActions;
(function (FileSystemActions) {
    FileSystemActions.writeFile = (file, data) => {
        if (!file) {
            throw new Error(`Invalid file information, unable to write: ${file}`);
        }
        Utils.writeFile(file, data);
    };
    FileSystemActions.readFile = (file) => {
        if (!file) {
            throw new Error(`Invalid file information, unable to read: ${file}`);
        }
        return Utils.readFile(file);
    };
    FileSystemActions.createDirectory = (directory) => {
        if (!directory) {
            throw new Error(`Invalid directory information, unable to create directory: ${directory}`);
        }
        Utils.makeDirectory(directory);
    };
    FileSystemActions.copyDirectoryContentsTo = (source, destination) => tslib_1.__awaiter(this, void 0, void 0, function* () {
        if (!source) {
            throw new Error(`Invalid source directory information, unable to copy directory: ${source}`);
        }
        if (!destination) {
            throw new Error(`Invalid destination directory information, unable to copy directory: ${destination}`);
        }
        yield Utils.copyFilesAsync(source, destination);
    });
    FileSystemActions.createPath = (...paths) => {
        return path_1.default.join(...paths);
    };
    FileSystemActions.replaceContent = (filePath, searchRegex, replaceValue) => {
        if (!filePath) {
            throw new Error(`Invalid file path information, unable to replace content: ${filePath}`);
        }
        if (!searchRegex) {
            throw new Error(`Invalid search regex: ${searchRegex}`);
        }
        if (replaceValue === undefined) {
            throw new Error(`Invalid replacement value: ${replaceValue}`);
        }
        const oldContent = Utils.readFile(filePath);
        const newContent = oldContent.replace(searchRegex, replaceValue);
        Utils.writeFile(filePath, newContent);
    };
    FileSystemActions.defaultFileFilterOptions = {
        nameBlacklist: ['.', 'dist', 'node_modules'],
    };
    FileSystemActions.listAllFiles = (directory, options = FileSystemActions.defaultFileFilterOptions) => {
        const { nameBlacklist = FileSystemActions.defaultFileFilterOptions.nameBlacklist, typeWhitelist } = options;
        const filter = (item) => {
            const basename = path_1.default.basename(item.path);
            const type = path_1.default.extname(item.path);
            const isLikelyTempHiddenSystem = basename[0] === '.';
            const isNameBlacklisted = nameBlacklist.includes(basename);
            const isTypeBlacklisted = type && typeWhitelist ? !typeWhitelist.includes(type) : false;
            const isSymbolicLink = item.stats.isSymbolicLink();
            return (!isLikelyTempHiddenSystem && !isNameBlacklisted && !isTypeBlacklisted && !isSymbolicLink);
        };
        return Utils.listAllFiles(directory, filter);
    };
})(FileSystemActions = exports.FileSystemActions || (exports.FileSystemActions = {}));
const setActionTypes = (plop) => {
    plop.setActionType(FileSystemActionType.createDirectory, (answers, config) => tslib_1.__awaiter(void 0, void 0, void 0, function* () {
        FileSystemActions.createDirectory(config.directory);
        return config.directory;
    }));
    plop.setActionType(FileSystemActionType.createPath, (answers, config) => tslib_1.__awaiter(void 0, void 0, void 0, function* () {
        const newPath = FileSystemActions.createPath(...config.paths);
        answers[config.answerKey] = newPath;
        return newPath;
    }));
    plop.setActionType(FileSystemActionType.replaceContent, (answers, config) => tslib_1.__awaiter(void 0, void 0, void 0, function* () {
        FileSystemActions.replaceContent(config.filePath, config.searchRegex, config.replaceValue);
        return config.filePath;
    }));
};
exports.setActionTypes = setActionTypes;
