import { NodePlopAPI } from 'node-plop';
import { Configure, DirectoryActionConfig, LocalSeedSource, RemoteSeedSource, SeedSources } from '../../seeds';
export declare enum SeedActionType {
    create = "Creating from seed",
    createFromDownload = "Creating from downloaded seed",
    createFromRemote = "Creating from remote seed",
    createFromLocal = "Creating from local seed",
    configure = "Configuring Seed",
    setEnvVars = "Writing environment variables"
}
export declare namespace SeedActionConfig {
    interface Create extends DirectoryActionConfig {
        get seed(): SeedSources;
        get seedDelivery(): string;
    }
    interface CreateFromDownload extends DirectoryActionConfig {
        get seed(): RemoteSeedSource;
    }
    interface CreateFromRemote extends DirectoryActionConfig {
        get seed(): RemoteSeedSource;
    }
    interface CreateFromLocal extends DirectoryActionConfig {
        get seed(): LocalSeedSource;
    }
    interface Configure extends DirectoryActionConfig {
        get seed(): SeedSources;
    }
    interface SetEnvVars extends DirectoryActionConfig {
    }
}
export declare namespace SeedActions {
    const createFromDownload: (directory: string, seed: RemoteSeedSource) => Promise<void>;
    const createFromRemote: (directory: string, seed: RemoteSeedSource) => Promise<void>;
    const createFromLocal: (directory: string, seed: LocalSeedSource) => Promise<void>;
    const create: (directory: string, seed: SeedSources, seedDelivery: string) => Promise<void>;
    const configure: Configure;
    interface EnvVars {
        dsName: string;
        pkgScope: string;
        pkgName: string;
        workspaceDirectory: string;
        workspaceName: string;
        workspaceId: string;
        managementToken: string;
        forceOverwrite: boolean;
    }
    const setEnvVars: (directory: string, envVars: EnvVars) => Promise<void>;
}
export declare const setActionTypes: (plop: NodePlopAPI) => void;
//# sourceMappingURL=seed.d.ts.map