"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.getSwitchDesignSystemGenerator = exports.switchDesignSystemGenerator = exports.switchDesignSystemDescription = void 0;
const tslib_1 = require("tslib");
const utils_1 = require("../../../utils");
const designSystem_1 = require("../../actions/designSystem");
const fileSystem_1 = require("../../actions/fileSystem");
const messages_1 = require("../../messages");
const generatorChain_1 = require("../generatorChain");
const analyzeComponentUsage_1 = require("./analyzeComponentUsage");
const applyRuntimeArgs = (prevAns = {}) => {
    if (prevAns.useCurrent === undefined) {
        prevAns.useCurrent = utils_1.argv.useCurrent;
    }
    if (!prevAns.targetDirectory) {
        prevAns.targetDirectory = utils_1.argv.targetDirectory;
    }
    if (!prevAns.newPrefix) {
        prevAns.newPrefix = utils_1.argv.newPrefix;
    }
    if (prevAns.hasOldCustomPrefix === undefined) {
        prevAns.hasOldCustomPrefix = utils_1.argv.hasOldCustomPrefix;
    }
    if (!prevAns.oldCustomPrefix) {
        prevAns.oldCustomPrefix = utils_1.argv.oldCustomPrefix;
    }
    return prevAns;
};
exports.switchDesignSystemDescription = 'Switch all design system prefixes found in files under the target directory to a new prefix, ie. templates, css rules, markdown etc.';
exports.switchDesignSystemGenerator = {
    description: (0, messages_1.generatorDescription)(exports.switchDesignSystemDescription),
    prompts(inquirer, prevAns = {}) {
        return tslib_1.__awaiter(this, void 0, void 0, function* () {
            prevAns = applyRuntimeArgs(prevAns);
            const { useCurrent = prevAns.useCurrent, targetDirectory = prevAns.targetDirectory, newPrefix = prevAns.newPrefix, hasOldCustomPrefix = prevAns.hasOldCustomPrefix, oldCustomPrefix = prevAns.oldCustomPrefix, proceed, } = yield inquirer.prompt([
                {
                    name: 'useCurrent',
                    type: 'confirm',
                    message: 'Use current directory',
                    when: !prevAns.targetDirectory,
                    default: false,
                },
                {
                    name: 'targetDirectory',
                    type: 'select-directory',
                    message: 'Target directory',
                    when: (data) => !prevAns.targetDirectory && !data.useCurrent,
                    basePath: utils_1.basePath,
                },
                {
                    name: 'newPrefix',
                    type: 'input',
                    message: 'New design system prefix',
                    when: !prevAns.newPrefix,
                },
                {
                    name: 'hasOldCustomPrefix',
                    type: 'confirm',
                    message: 'Files are currently using a custom design system prefix',
                    when: !prevAns.hasOldCustomPrefix || !prevAns.oldCustomPrefix,
                    default: false,
                },
                {
                    name: 'oldCustomPrefix',
                    type: 'input',
                    message: 'Custom design system prefix to replace',
                    when: (data) => !prevAns.oldCustomPrefix && data.hasOldCustomPrefix,
                },
                {
                    name: 'proceed',
                    type: 'confirm',
                    message: 'Please review selections. Proceed with operation',
                    default: true,
                },
            ]);
            return {
                useCurrent,
                targetDirectory: useCurrent ? process.cwd() : targetDirectory,
                newPrefix,
                hasOldCustomPrefix,
                oldCustomPrefix,
                proceed,
            };
        });
    },
    actions: (answers) => {
        if (!answers.proceed) {
            return ['Operation aborted.'];
        }
        const actions = [];
        const filePaths = fileSystem_1.FileSystemActions.listAllFiles(answers.targetDirectory);
        filePaths.forEach((filePath) => {
            actions.push({
                type: designSystem_1.DesignSystemActionType.switchPrefixes,
                get filePath() {
                    return filePath;
                },
                get newPrefix() {
                    return answers.newPrefix;
                },
                get oldCustomPrefix() {
                    return answers.oldCustomPrefix;
                },
                abortOnFail: true,
            });
        });
        actions.push(' Design system prefixes switched successfully! 🎉 Please crosscheck changes in git.');
        return actions;
    },
};
const getSwitchDesignSystemGenerator = (plop, bypassArr) => ({
    name: 'switch design system',
    generator: (0, generatorChain_1.generatorChain)(plop, (0, messages_1.generatorDescription)(exports.switchDesignSystemDescription), [exports.switchDesignSystemGenerator, analyzeComponentUsage_1.analyzeComponentUsageGenerator], bypassArr),
});
exports.getSwitchDesignSystemGenerator = getSwitchDesignSystemGenerator;
