"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.tagForReportUsage = exports.componentReportUsage = exports.componentRegisterCodeToken = void 0;
const format_1 = require("../format");
const link_1 = require("../link");
const componentRegisterCodeToken = (componentName) => {
    switch (componentName) {
        case 'zero-option':
            return `zeroListboxOption`;
        case 'foundation-option':
            return `foundationListboxOption`;
        default:
            return `${format_1.Format.transform.camelCase(componentName)}`;
    }
};
exports.componentRegisterCodeToken = componentRegisterCodeToken;
const componentReportUsage = (components) => {
    const uniqueComponents = [...new Set(components)];
    if (!uniqueComponents.length) {
        console.log('No components usage to report');
        return;
    }
    const output = uniqueComponents.sort().join('\n');
    console.log(`
Based on analysis you will need to register the following components:

${output}
    `);
};
exports.componentReportUsage = componentReportUsage;
const tagForReportUsage = (components, inAddition) => {
    const uniqueComponents = [...new Set(components)];
    if (!uniqueComponents.length) {
        console.log('No components usage to report');
        return;
    }
    const output = uniqueComponents.sort().join('\n');
    const tagForLink = (0, link_1.createLink)('https://github.com/microsoft/fast/blob/master/packages/web-components/fast-foundation/src/patterns/tag-for.ts#L17', 'tagFor');
    const pretext = inAddition ? 'You will also' : 'Based on analysis you will';
    console.log(`
${pretext} need to register and provide mappings for the following 'tagFor' based components:

${output}

See ${tagForLink} for more information.
`);
};
exports.tagForReportUsage = tagForReportUsage;
