"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.getSeedConfigurationUtils = exports.rename = exports.listAllFiles = exports.defaultSort = exports.combineArrays = exports.replaceObjectKeys = exports.getDirectoryInfo = exports.getWriteFileWithData = exports.writeFileWithAnswers = exports.writeFile = exports.readFile = exports.copyFilesAsync = exports.copyFilesAsyncOptions = exports.copyFiles = exports.copyFilesOptions = exports.makeDirectory = exports.directoryExists = exports.getCurrentDirectoryBase = exports.getBaseComponentSchema = exports.getBaseComponentsDirectories = exports.getUIAuthoringConfig = exports.getDsDirectoryNames = exports.getUIDirectoryNames = exports.getDirectoryNames = exports.getDesignSystemsDirectories = exports.getMSFastComponentsPath = exports.getDSPath = exports.getFoundationUIPath = exports.getByName = exports.mapToSeedChoices = exports.mapToListChoices = exports.mapToKeyValues = exports.mapToCheckboxChoices = exports.mapToNames = exports.getDirectories = exports.progressSpinner = exports.basePath = exports.env = exports.argv = void 0;
const tslib_1 = require("tslib");
const os_1 = tslib_1.__importDefault(require("os"));
const path_1 = tslib_1.__importDefault(require("path"));
const edit_json_file_1 = tslib_1.__importDefault(require("edit-json-file"));
const fs_extra_1 = tslib_1.__importDefault(require("fs-extra"));
const klaw_sync_1 = tslib_1.__importDefault(require("klaw-sync"));
const plop_1 = require("plop");
const yargs_parser_1 = tslib_1.__importDefault(require("yargs-parser"));
const errors_1 = require("../errors");
const store_1 = require("../store");
const ignoreArgvCount = 2;
exports.argv = (0, yargs_parser_1.default)(process.argv.slice(ignoreArgvCount));
exports.env = process.env;
exports.basePath = os_1.default.homedir();
exports.progressSpinner = plop_1.progressSpinner;
const getDirectories = (relativePath) => fs_extra_1.default
    .readdirSync(path_1.default.resolve(__dirname, relativePath), { withFileTypes: true })
    .filter((dirent) => dirent.isDirectory())
    .map((dirent) => ({ key: dirent.name, value: dirent.name }));
exports.getDirectories = getDirectories;
const mapToNames = (pairs, field = 'key') => pairs.map((p) => p[field]);
exports.mapToNames = mapToNames;
const mapToCheckboxChoices = (pairs, nameField = 'key', valueField = 'value') => pairs.map((p) => ({ type: 'choice', name: p[nameField], value: p[valueField] }));
exports.mapToCheckboxChoices = mapToCheckboxChoices;
const mapToKeyValues = (options) => options.map((option) => ({ key: option.name, value: option }));
exports.mapToKeyValues = mapToKeyValues;
const mapToListChoices = (pairs) => pairs.map((p) => ({ type: 'choice', name: p.key, value: p.value }));
exports.mapToListChoices = mapToListChoices;
const mapToSeedChoices = (seeds) => (0, exports.mapToListChoices)((0, exports.mapToKeyValues)(seeds));
exports.mapToSeedChoices = mapToSeedChoices;
const getByName = (array, name) => array.find((el) => el.name === name);
exports.getByName = getByName;
const getFoundationUIPath = () => path_1.default.resolve(__dirname, '../../../../foundation/foundation-ui/src');
exports.getFoundationUIPath = getFoundationUIPath;
const getDSPath = (name) => path_1.default.resolve(__dirname, `../../../../foundation/foundation-ds/${name}/src`);
exports.getDSPath = getDSPath;
const getMSFastComponentsPath = () => path_1.default.resolve(__dirname, '../../../../../node_modules/@microsoft/fast-components/dist/dts');
exports.getMSFastComponentsPath = getMSFastComponentsPath;
const getDesignSystemsDirectories = () => (0, exports.getDirectories)('../../../../foundation/foundation-ds');
exports.getDesignSystemsDirectories = getDesignSystemsDirectories;
const getDirectoryNames = (dirPath) => (0, exports.mapToNames)((0, exports.getDirectories)(dirPath));
exports.getDirectoryNames = getDirectoryNames;
const getUIDirectoryNames = () => (0, exports.getDirectoryNames)((0, exports.getFoundationUIPath)());
exports.getUIDirectoryNames = getUIDirectoryNames;
const getDsDirectoryNames = (dsName) => (0, exports.getDirectoryNames)((0, exports.getDSPath)(dsName));
exports.getDsDirectoryNames = getDsDirectoryNames;
const getUIAuthoringConfig = () => require(`${(0, exports.getFoundationUIPath)()}/../authoring.config.json`);
exports.getUIAuthoringConfig = getUIAuthoringConfig;
const getBaseComponentsDirectories = () => (0, exports.getDirectories)((0, exports.getMSFastComponentsPath)());
exports.getBaseComponentsDirectories = getBaseComponentsDirectories;
const getBaseComponentSchema = (name) => require(`${(0, exports.getMSFastComponentsPath)()}/../esm/${name}/${name}.open-ui.definition.json`);
exports.getBaseComponentSchema = getBaseComponentSchema;
const getCurrentDirectoryBase = () => path_1.default.basename(process.cwd());
exports.getCurrentDirectoryBase = getCurrentDirectoryBase;
const directoryExists = (directory) => fs_extra_1.default.existsSync(directory);
exports.directoryExists = directoryExists;
const makeDirectory = (directory) => {
    if (!(0, exports.directoryExists)(directory)) {
        fs_extra_1.default.mkdirSync(directory);
    }
};
exports.makeDirectory = makeDirectory;
const copyFilter = (src) => src.indexOf('node_modules') === -1 && src.indexOf('.git') === -1 && src.indexOf('.idea') === -1;
exports.copyFilesOptions = {
    filter: copyFilter,
};
const copyFiles = (source, destination, options = exports.copyFilesOptions) => {
    try {
        fs_extra_1.default.copySync(source, destination, options);
    }
    catch (error) {
        (0, errors_1.errorHandler)(error);
    }
};
exports.copyFiles = copyFiles;
exports.copyFilesAsyncOptions = {
    filter: function copyPath(src, dist) {
        return tslib_1.__awaiter(this, void 0, void 0, function* () {
            const result = copyFilter(src);
            return result;
        });
    },
};
const copyFilesAsync = (source, destination, options = exports.copyFilesAsyncOptions) => tslib_1.__awaiter(void 0, void 0, void 0, function* () {
    try {
        yield fs_extra_1.default.copy(source, destination, options);
    }
    catch (error) {
        (0, errors_1.errorHandler)(error);
    }
});
exports.copyFilesAsync = copyFilesAsync;
const readFile = (file) => fs_extra_1.default.readFileSync(file, 'utf8');
exports.readFile = readFile;
const writeFile = (file, data) => fs_extra_1.default.writeFileSync(file, data, 'utf8');
exports.writeFile = writeFile;
const writeFileWithAnswers = (file, plop, answers, template) => {
    const input = (0, exports.readFile)(template || file);
    const output = plop.renderString(input, answers);
    (0, exports.writeFile)(file, output);
};
exports.writeFileWithAnswers = writeFileWithAnswers;
const getWriteFileWithData = (plop) => (file, answers, template) => (0, exports.writeFileWithAnswers)(file, plop, answers, template);
exports.getWriteFileWithData = getWriteFileWithData;
const getDirectoryInfo = (dirPath) => {
    const resolvedPath = path_1.default.resolve(__dirname, dirPath);
    if (!(0, exports.directoryExists)(resolvedPath)) {
        return null;
    }
    const contents = (0, exports.getDirectoryNames)(resolvedPath);
    let packagePath = path_1.default.resolve(resolvedPath, `../package.json`);
    if (!(0, exports.directoryExists)(packagePath)) {
        packagePath = path_1.default.resolve(resolvedPath, `../../package.json`);
    }
    try {
        const packageJSON = require(packagePath);
        return {
            contents,
            name: packageJSON.name,
            version: packageJSON.version,
        };
    }
    catch (e) {
        console.error(e);
        return null;
    }
};
exports.getDirectoryInfo = getDirectoryInfo;
const replaceObjectKeys = (input, searchValue, replaceValue) => Object.fromEntries(Object.entries(input).map(([key, value]) => [key.replace(searchValue, replaceValue), value]));
exports.replaceObjectKeys = replaceObjectKeys;
const combineArrays = (a1, a2) => {
    const temp = [...a1];
    a2.forEach((item) => {
        if (!temp.includes(item)) {
            temp.push(item);
        }
    });
    temp.sort();
    return temp;
};
exports.combineArrays = combineArrays;
const defaultSort = (a, b) => {
    if (a < b) {
        return -1;
    }
    if (a > b) {
        return 1;
    }
    return 0;
};
exports.defaultSort = defaultSort;
const listAllFiles = (rootFolder, fileFilter) => {
    return (0, klaw_sync_1.default)(rootFolder, {
        nodir: true,
        filter: fileFilter,
    }).map((i) => i.path);
};
exports.listAllFiles = listAllFiles;
const rename = (oldPath, newPath) => {
    fs_extra_1.default.renameSync(oldPath, newPath);
};
exports.rename = rename;
const getSeedConfigurationUtils = (plop) => ({
    configStore: store_1.configStore,
    plop,
    progressSpinner: exports.progressSpinner,
    editJSONFile: edit_json_file_1.default,
    readFile: exports.readFile,
    writeFile: exports.writeFile,
    writeFileWithData: (0, exports.getWriteFileWithData)(plop),
    copyFiles: exports.copyFiles,
    copyFilesAsync: exports.copyFilesAsync,
    replaceObjectKeys: exports.replaceObjectKeys,
    directoryExists: exports.directoryExists,
    makeDirectory: exports.makeDirectory,
    listAllFiles: exports.listAllFiles,
    rename: exports.rename,
});
exports.getSeedConfigurationUtils = getSeedConfigurationUtils;
